==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/realm/entity/MapAuthenticationFlowEntityFields.java <==
package org.keycloak.models.map.realm.entity;
public enum MapAuthenticationFlowEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e) {
            return (String) e.getId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e, T value) {
            e.setId((String) value);
        }
    },
    ALIAS {
        public static final String FIELD_NAME = "Alias";
        public static final String FIELD_NAME_DASHED = "alias";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e, T value) {
            e.setAlias((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e) {
            return (String) e.getAlias();
        }
    },
    BUILT_IN {
        public static final String FIELD_NAME = "BuiltIn";
        public static final String FIELD_NAME_DASHED = "built-in";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e) {
            return (Boolean) e.isBuiltIn();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e, T value) {
            e.setBuiltIn((Boolean) value);
        }
    },
    DESCRIPTION {
        public static final String FIELD_NAME = "Description";
        public static final String FIELD_NAME_DASHED = "description";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e) {
            return (String) e.getDescription();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e, T value) {
            e.setDescription((String) value);
        }
    },
    PROVIDER_ID {
        public static final String FIELD_NAME = "ProviderId";
        public static final String FIELD_NAME_DASHED = "provider-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e) {
            return (String) e.getProviderId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e, T value) {
            e.setProviderId((String) value);
        }
    },
    TOP_LEVEL {
        public static final String FIELD_NAME = "TopLevel";
        public static final String FIELD_NAME_DASHED = "top-level";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e, T value) {
            e.setTopLevel((Boolean) value);
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e) {
            return (Boolean) e.isTopLevel();
        }
    },
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapAuthenticationFlowEntityFields.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public enum MapAuthenticationFlowEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        public static final String FIELD_NAME_CAMEL_CASE = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e, T value) {
            e.setId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e) {
            return (String) e.getId();
        }
    },
    ALIAS {
        public static final String FIELD_NAME = "Alias";
        public static final String FIELD_NAME_DASHED = "alias";
        public static final String FIELD_NAME_CAMEL_CASE = "alias";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e, T value) {
            e.setAlias((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e) {
            return (String) e.getAlias();
        }
    },
    BUILT_IN {
        public static final String FIELD_NAME = "BuiltIn";
        public static final String FIELD_NAME_DASHED = "built-in";
        public static final String FIELD_NAME_CAMEL_CASE = "builtIn";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e) {
            return (Boolean) e.isBuiltIn();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e, T value) {
            e.setBuiltIn((Boolean) value);
        }
    },
    DESCRIPTION {
        public static final String FIELD_NAME = "Description";
        public static final String FIELD_NAME_DASHED = "description";
        public static final String FIELD_NAME_CAMEL_CASE = "description";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e, T value) {
            e.setDescription((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e) {
            return (String) e.getDescription();
        }
    },
    PROVIDER_ID {
        public static final String FIELD_NAME = "ProviderId";
        public static final String FIELD_NAME_DASHED = "provider-id";
        public static final String FIELD_NAME_CAMEL_CASE = "providerId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e, T value) {
            e.setProviderId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e) {
            return (String) e.getProviderId();
        }
    },
    TOP_LEVEL {
        public static final String FIELD_NAME = "TopLevel";
        public static final String FIELD_NAME_DASHED = "top-level";
        public static final String FIELD_NAME_CAMEL_CASE = "topLevel";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e, T value) {
            e.setTopLevel((Boolean) value);
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity e) {
            return (Boolean) e.isTopLevel();
        }
    },
}
